<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\ClientInvestmentRequest;
use App\Http\Resources\ClientInvestmentResource;
use App\Models\ClientInvestment;
use Illuminate\Http\JsonResponse;

class ClientInvestmentController extends Controller
{
    protected array $relations = ["client"];

    /**
     * Display a listing of the clientInvestments.
     */
    public function index(): JsonResponse {
        $clientInvestments = $this->paginateOrGet(
            ClientInvestment::with($this->relations)->latest());

        return $this->respondWithResourceCollection(
            ClientInvestmentResource::collection($clientInvestments)
        );
    }

    /**
     * Store a newly created clientInvestment in storage.
     */
    public function store(ClientInvestmentRequest $request): JsonResponse {
        $clientInvestment = ClientInvestment::create($request->validated());

        return $this->respondCreated(
            new ClientInvestmentResource($clientInvestment),
            "ClientInvestment created successfully!"
        );
    }

    /**
     * Display the specified clientInvestment.
     */
    public function show(ClientInvestment $clientInvestment): JsonResponse {
        $clientInvestment->loadMissing($this->relations);

        return $this->respondWithResource(new ClientInvestmentResource($clientInvestment));
    }

    /**
     * Update the specified clientInvestment in storage.
     */
    public function update(ClientInvestmentRequest $request, ClientInvestment $clientInvestment): JsonResponse {
        $clientInvestment->update($request->validated());

        return $this->respondUpdated(
            new ClientInvestmentResource($clientInvestment),
            "ClientInvestment updated successfully!"
        );
    }

    /**
     * Remove the specified clientInvestment from storage.
     */
    public function destroy(ClientInvestment $clientInvestment): JsonResponse {
        $clientInvestment->delete();

        return $this->respondSuccess("ClientInvestment deleted successfully!");
    }
}
