<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\CommissionSlabRequest;
use App\Http\Resources\CommissionSlabResource;
use App\Models\CommissionSlab;
use Illuminate\Http\JsonResponse;

class CommissionSlabController extends Controller
{
    /**
     * Display a listing of the commissionSlabs.
     */
    public function index(): JsonResponse {
        $commissionSlabs = CommissionSlab::latest()->get();

        return $this->respondWithResourceCollection(
            CommissionSlabResource::collection($commissionSlabs)
        );
    }

    /**
     * Store a newly created commissionSlab in storage.
     */
    public function store(CommissionSlabRequest $request): JsonResponse {
        $commissionSlab = CommissionSlab::create($request->validated());

        return $this->respondCreated(
            new CommissionSlabResource($commissionSlab),
            "CommissionSlab created successfully!"
        );
    }

    /**
     * Display the specified commissionSlab.
     */
    public function show(CommissionSlab $commissionSlab): JsonResponse {
        return $this->respondWithResource(new CommissionSlabResource($commissionSlab));
    }

    /**
     * Update the specified commissionSlab in storage.
     */
    public function update(CommissionSlabRequest $request, CommissionSlab $commissionSlab): JsonResponse {
        $commissionSlab->update($request->validated());

        return $this->respondUpdated(
            new CommissionSlabResource($commissionSlab),
            "CommissionSlab updated successfully!"
        );
    }

    /**
     * Remove the specified commissionSlab from storage.
     */
    public function destroy(CommissionSlab $commissionSlab): JsonResponse {
        $commissionSlab->delete();

        return $this->respondSuccess("CommissionSlab deleted successfully!");
    }
}
