<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\DailyUpdateRequest;
use App\Http\Resources\DailyUpdateResource;
use App\Imports\InvestmentImport;
use App\Models\DailyUpdate;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;

class DailyUpdateController extends Controller
{
    protected array $relations = [
        "client"
    ];

    /**
     * Display a listing of the dailyUpdates.
     */
    public function index(): JsonResponse {
        $dailyUpdates = $this->paginateOrGet(
            DailyUpdate::filter()->latest("id"));

        return $this->respondWithResourceCollection(
            DailyUpdateResource::collection($dailyUpdates)
        );
    }

    /**
     * Store a newly created dailyUpdate in storage.
     */
    public function store(DailyUpdateRequest $request): JsonResponse {
        $dailyUpdate = DailyUpdate::create($request->validated());

        return $this->respondCreated(
            new DailyUpdateResource($dailyUpdate),
            "DailyUpdate created successfully!"
        );
    }

    /**
     * Display the specified dailyUpdate.
     */
    public function show(DailyUpdate $dailyUpdate): JsonResponse {
        $dailyUpdate->loadMissing($this->relations);

        return $this->respondWithResource(new DailyUpdateResource($dailyUpdate));
    }

    /**
     * Update the specified dailyUpdate in storage.
     */
    public function update(DailyUpdateRequest $request, DailyUpdate $dailyUpdate): JsonResponse {
        $dailyUpdate->update($request->validated());

        return $this->respondUpdated(
            new DailyUpdateResource($dailyUpdate),
            "DailyUpdate updated successfully!"
        );
    }

    /**
     * Remove the specified dailyUpdate from storage.
     */
    public function destroy(DailyUpdate $dailyUpdate): JsonResponse {
        $dailyUpdate->delete();

        return $this->respondSuccess("DailyUpdate deleted successfully!");
    }

    public function upload(Request $request) {
        $request->validate([
            "file" => ["required", "file", "mimes:xlsx"]
        ]);

        Excel::import(new InvestmentImport(), $request->file("file"));

        return $this->respondSuccess(
            "File processed successfully!",
            DailyUpdateResource::collection(DailyUpdate::latest("id")->get())
        );
    }
}
