<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\FollowUpRequest;
use App\Http\Resources\FollowUpResource;
use App\Models\FollowUp;
use Illuminate\Http\JsonResponse;

class FollowUpController extends Controller
{
    protected array $relations = ["lead"];

    /**
     * Display a listing of the followUps.
     */
    public function index(): JsonResponse {
        $followUps = $this->paginateOrGet(
            FollowUp::with($this->relations)->filter()->latest());

        return $this->respondWithResourceCollection(
            FollowUpResource::collection($followUps)
        );
    }

    /**
     * Store a newly created followUp in storage.
     */
    public function store(FollowUpRequest $request): JsonResponse {
        $followUp = FollowUp::create($request->validated());

        return $this->respondCreated(
            new FollowUpResource($followUp),
            "FollowUp created successfully!"
        );
    }

    /**
     * Display the specified followUp.
     */
    public function show(FollowUp $followUp): JsonResponse {
        $followUp->loadMissing($this->relations);

        return $this->respondWithResource(new FollowUpResource($followUp));
    }

    /**
     * Update the specified followUp in storage.
     */
    public function update(FollowUpRequest $request, FollowUp $followUp): JsonResponse {
        $followUp->update($request->validated());

        return $this->respondUpdated(
            new FollowUpResource($followUp),
            "FollowUp updated successfully!"
        );
    }

    /**
     * Remove the specified followUp from storage.
     */
    public function destroy(FollowUp $followUp): JsonResponse {
        $followUp->delete();

        return $this->respondSuccess("FollowUp deleted successfully!");
    }
}
