<?php

namespace App\Http\Requests;

use App\Enums\DistributorStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class DistributorRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'user_id' => ['nullable', 'exists:users,id'],
            'approved_by_id' => ['nullable', 'exists:users,id'],

            'reference_id' => ['nullable', 'string', 'max:254'],
            'name' => ['required', 'string', 'max:254'],
            'email' => ['required', 'email', 'max:254', Rule::unique("distributors")],
            'mobile_no' => ['nullable', 'string', 'max:20'],
            'address' => ['nullable', 'string', 'max:254'],
            'city' => ['required', 'string', 'max:50'],
            'commission_percentage' => ['nullable', 'numeric', 'between:0,999.99'],
            'status' => ['sometimes', Rule::enum(DistributorStatus::class)],
        ];

        if ($this->routeIs("distributors.update")) {
            // get the model or ID from the route parameter
            $distributorId = $this->route('distributor');

            $rules["city"][0] = "sometimes";
            $rules["email"][0] = "sometimes";
            // Ignore email for the current lead
            $rules["email"][3] = Rule::unique("leads")->ignore($distributorId);
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
