<?php

namespace App\Http\Requests;

use App\Enums\ClientStatus;
use App\Enums\ClientType;
use App\Enums\LeadStatus;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class LeadRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'user_id' => ['nullable', 'exists:users,id'],
            'created_by_id' => ['required', 'exists:users,id'],
            'assigned_to_id' => ['nullable', 'exists:users,id'],
            'rm_id' => ['required', 'exists:users,id'],
            'distributor_id' => ['required', 'exists:users,id'],

            'name' => ['required', 'string', 'max:254'],
            'email' => ['required', 'email', 'max:254', Rule::unique("leads")],
            'mobile_no' => ['nullable', 'string', 'max:20'],
            'remarks' => ['nullable', 'string'],
            'desired_investment_amount' => ['nullable', 'integer'],
            'initial_investment_date' => ['nullable', 'date'],
            'initial_invested_amount' => ['nullable', 'integer'],
            'current_invested_amount' => ['nullable', 'integer'],
            'current_investment_value' => ['nullable', 'integer'],
            'mother_name' => ['nullable'],
            'cheque_no' => ['nullable'],
            'is_client' => ['sometimes', 'boolean'],
            'is_onboarded' => ['sometimes', 'boolean'],

            'lead_status' => ['sometimes', Rule::enum(LeadStatus::class)],
            'client_status' => ['nullable', Rule::enum(ClientStatus::class)],
            'client_type' => ['nullable', Rule::enum(ClientType::class)],

            'aadhar' => $this->hasFile('aadhar')
                ? ['file', 'max:2048']
                : ['nullable', 'string'],
            'pan' => $this->hasFile('pan')
                ? ['file', 'max:2048']
                : ['nullable', 'string'],
            'signature' => $this->hasFile('signature')
                ? ['file', 'max:2048']
                : ['nullable', 'string'],
            'photo' => $this->hasFile('photo')
                ? ['file', 'max:2048']
                : ['nullable', 'string'],
        ];

        if ($this->routeIs("leads.update")) {
            // Get the model or ID from the route parameter
            $leadId = $this->route('lead');

            $rules["created_by_id"][0] = "sometimes";
            $rules["rm_id"][0] = "sometimes";
            $rules["distributor_id"][0] = "sometimes";
            $rules["name"][0] = "sometimes";
            $rules["email"][0] = "sometimes";
            // Ignore email for the current lead
            $rules["email"][3] = Rule::unique("leads")->ignore($leadId);
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
