<?php

namespace App\Http\Resources;

use App\Models\Lead;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Lead */
class LeadResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'user_id' => $this->user_id,
            'created_by_id' => $this->created_by_id,
            'assigned_to_id' => $this->assigned_to_id,
            'rm_id' => $this->rm_id,
            'distributor_id' => $this->distributor_id,

            'name' => $this->name,
            'email' => $this->email,
            'mobile_no' => $this->mobile_no,
            'remarks' => $this->remarks,
            'desired_investment_amount' => $this->desired_investment_amount,
            'initial_investment_date' => $this->initial_investment_date,
            'initial_invested_amount' => $this->initial_invested_amount,
            'current_invested_amount' => $this->current_invested_amount,
            'current_investment_value' => $this->current_investment_value,
            'mother_name' => $this->mother_name,
            'cheque_no' => $this->cheque_no,
            'is_client' => $this->is_client,
            'is_onboarded' => $this->is_onboarded,
            'lead_status' => $this->lead_status,
            'client_status' => $this->client_status,
            'client_type' => $this->client_type,
            'converted_at' => $this->converted_at,

            // file uploads
            'aadhar' => $this->aadhar,
            'pan' => $this->pan,
            'signature' => $this->signature,
            'photo' => $this->photo,

            // relations
            'user' => new UserResource($this->whenLoaded('user')),
            'created_by' => new UserResource($this->whenLoaded('createdBy')),
            'assigned_to' => new UserResource($this->whenLoaded('assignedTo')),
            'rm' => new UserResource($this->whenLoaded('rm')),
            'distributor' => new UserResource($this->whenLoaded('distributor')),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
