<?php

namespace App\Imports;

use App\Models\DailyUpdate;
use App\Models\Lead;
use Carbon\Carbon;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\ToCollection;
use Maatwebsite\Excel\Concerns\WithHeadingRow;

class InvestmentImport implements ToCollection, WithHeadingRow
{
    /**
     * @param  Collection  $collection
     */
    public function collection(Collection $collection): void {
        $dailyUpdates = [];

        foreach ($collection as $row) {
            // convert Excel serial date to a readable date
            $date = Carbon::createFromFormat(
                'Y-m-d', gmdate('Y-m-d', ($row['date'] - 25569) * 86400))->toDateString();

            // find lead by client_id
            $lead = Lead::find($row['client_id']);

            $lead?->update([
                'current_investment_value' => $row['amount']
            ]);

            $dailyUpdates[] = [
                "client_id" => $row["client_id"],
                "name" => $row["name"],
                "date" => $date,
                "amount" => $row["amount"],
                "created_at" => now()
            ];
        }

        DailyUpdate::insert($dailyUpdates);
    }
}
