<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Distributor extends Model
{
    use HasFactory, Filterable;

    public $filterFields = [
        "distributor_id",
        "reference_id",
        "city",
        "status",
    ];

    protected $fillable = [
        'user_id',
        'approved_by_id',

        'reference_id',
        'name',
        'email',
        'mobile_no',
        'address',
        'city',
        'commission_percentage',
        'status',
    ];

    // Automatically generate the distributor_id
    protected static function boot(): void {
        parent::boot();

        // Before creating a distributor, set the distributor_id
        static::creating(function ($distributor) {
            $distributor->distributor_id = self::generateDistributorId();
        });
    }

    /**
     * Generate a new distributor_id with the format SI1111, SI1112, ...
     */
    public static function generateDistributorId(): string {
        // Get the last distributor by distributor_id
        $lastDistributor = self::orderBy('id', 'desc')->first();

        // Default starting number (SI1111)
        $prefix = 'SI';
        $startNumber = 1111;

        if (!$lastDistributor) {
            // No distributor yet, return the first one
            return $prefix.$startNumber;
        }

        // Get the numeric part from the last distributor_id and increment it
        $lastNumber = (int) substr($lastDistributor->distributor_id, 2); // Remove the prefix "SI"
        $newNumber = $lastNumber + 1;

        // Return the new distributor_id in the format SI1111, SI1112, etc.
        return $prefix.$newNumber;
    }

    public function user(): BelongsTo {
        return $this->belongsTo(User::class);
    }

    public function approvedBy(): BelongsTo {
        return $this->belongsTo(User::class, 'approved_by_id');
    }
}
