<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use App\Enums\LeadStatus;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Lead extends Model
{
    use HasFactory, Filterable;

    const MAX_NOMINEES = 3;
    public $filterFields = [
        'user_id',
        'created_by_id',
        'assigned_to_id',
        'rm_id',
        'distributor_id',
        
        'name',
        'email',
        'lead_status',
        'client_status',
        'client_type',
        'is_client'
    ];

    protected $attributes = [
        "lead_status" => LeadStatus::NEW->value,
        "is_client" => false,
        "is_mailed" => false,
        "is_onboarded" => false
    ];

    protected $fillable = [
        'user_id',
        'created_by_id',
        'assigned_to_id',
        'rm_id',
        'distributor_id',

        'name',
        'email',
        'mobile_no',
        'remarks',
        'desired_investment_amount',
        'initial_invested_amount',
        'initial_investment_date',
        'current_invested_amount',
        'current_investment_value',
        'mother_name',
        'cheque_no',
        'is_client',
        'is_onboarded',
        'lead_status',
        'client_status',
        'client_type',
        'converted_at'
    ];

    public function user(): BelongsTo {
        return $this->belongsTo(User::class, "user_id");
    }

    public function createdBy(): BelongsTo {
        return $this->belongsTo(User::class, 'created_by_id');
    }

    public function assignedTo(): BelongsTo {
        return $this->belongsTo(User::class, 'assigned_to_id');
    }

    public function rm(): BelongsTo {
        return $this->belongsTo(User::class, "rm_id");
    }

    public function distributor(): BelongsTo {
        return $this->belongsTo(User::class, 'distributor_id');
    }

    public function clientNominees(): HasMany {
        return $this->hasMany(ClientNominee::class, "client_id");
    }

    public function clientInvestments(): HasMany {
        return $this->hasMany(ClientInvestment::class, "client_id");
    }

    protected function casts(): array {
        return [
            'initial_investment_date' => 'date',
        ];
    }
}
