<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Auth\Passwords\CanResetPassword as CanResetPasswordTrait;
use Illuminate\Contracts\Auth\CanResetPassword as CanResetPasswordContract;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Model implements CanResetPasswordContract
{
    use HasFactory, Notifiable, HasApiTokens, Filterable, CanResetPasswordTrait;

    public $filterFields = [
        "name",
        "email",
        "role",
        "is_active"
    ];

    protected $fillable = [
        'super_admin_id',
        'admin_id',
        'rm_id',
        'distributor_id',

        'name',
        'email',
        'mobile_no',
        'password',
        'role',
        'is_active',
        'last_login_at',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    public function superAdmin(): BelongsTo {
        return $this->belongsTo(User::class, 'super_admin_id');
    }

    public function admin(): BelongsTo {
        return $this->belongsTo(User::class, 'admin_id');
    }

    public function rm(): BelongsTo {
        return $this->belongsTo(User::class, 'rm_id');
    }

    public function distributor(): BelongsTo {
        return $this->belongsTo(User::class, 'distributor_id');
    }

    public function userClient(): HasOne {
        return $this->hasOne(Lead::class, "user_id");
    }

    public function userDistributor(): HasOne {
        return $this->hasOne(Distributor::class, "user_id");
    }

    public function distributorLeads(): HasMany {
        return $this->hasMany(Lead::class, "distributor_id");
    }

    protected function casts(): array {
        return [
            'password' => 'hashed',
        ];
    }
}

