<?php

use App\Enums\ClientStatus;
use App\Enums\ClientType;
use App\Enums\LeadStatus;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    public function up(): void {
        Schema::create('leads', function (Blueprint $table) {
            $table->id();

            $table->foreignId('user_id')->nullable()->constrained("users")
                ->nullOnDelete();
            $table->foreignId('created_by_id')->nullable()->constrained("users")
                ->nullOnDelete();
            $table->foreignId('assigned_to_id')->nullable()->constrained("users")
                ->nullOnDelete();
            $table->foreignId('rm_id')->nullable()->constrained("users")
                ->nullOnDelete();
            $table->foreignId('distributor_id')->nullable()->constrained("users")
                ->nullOnDelete();

            $table->string('name');
            $table->string('email')->unique();
            $table->string('mobile_no', 20)->nullable();
            $table->text('remarks')->nullable();
            $table->unsignedInteger('desired_investment_amount')->nullable();
            $table->enum('lead_status', array_column(LeadStatus::cases(), "value"))->default(LeadStatus::NEW->value);

            $table->date('initial_investment_date')->nullable();
            $table->unsignedInteger("initial_invested_amount")->nullable();
            $table->unsignedInteger('current_invested_amount')->nullable();
            $table->unsignedInteger('current_investment_value')->nullable();
            $table->string('mother_name')->nullable();
            $table->string('cheque_no', 20)->nullable();
            $table->boolean('is_client')->default(false);
            $table->boolean('is_onboarded')->default(false);
            $table->boolean("is_mailed")->default(false);
            $table->timestamp("converted_at")->nullable();
            $table->enum('client_status', array_column(ClientStatus::cases(), "value"))->nullable();
            $table->enum('client_type', array_column(ClientType::cases(), "value"))->nullable();

            $table->string('aadhar', 100)->nullable();
            $table->string('pan', 100)->nullable();
            $table->string('signature', 100)->nullable();
            $table->string('photo', 100)->nullable();

            $table->timestamps();
        });
    }

    public function down(): void {
        Schema::dropIfExists('leads');
    }
};
