<?php

namespace Database\Seeders;

use App\Enums\ClientStatus;
use App\Enums\DistributorStatus;
use App\Enums\LeadStatus;
use App\Enums\UserRole;
use App\Models\ClientInvestment;
use App\Models\ClientNominee;
use App\Models\Distributor;
use App\Models\FollowUp;
use App\Models\Lead;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Database\Seeder;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;
class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void {
        $superAdmin = User::factory()->create([
            'name' => 'Super Admin',
            'email' => 'super-admin@seven-islands.com',
            'role' => UserRole::SUPER_ADMIN->value
        ]);

        $admin = User::factory()->create([
            'super_admin_id' => $superAdmin->id,
            'name' => 'Admin',
            'email' => 'admin@admin.com',
            'role' => UserRole::ADMIN->value,
        ]);

        $rm = User::factory()->create([
            'super_admin_id' => $superAdmin->id,
            'admin_id' => $admin,
            "name" => "Employee",
            "email" => "rm@seven-islands.com",
            'role' => UserRole::RM->value,
        ]);

        $distributor = Distributor::factory()->create([
            "approved_by_id" => $rm->id,
            "status" => DistributorStatus::APPROVED->value,
        ]);

        $distributorUser = User::factory()->create([
            'super_admin_id' => $superAdmin->id,
            'admin_id' => $admin,
            'rm_id' => $rm->id,
            'role' => UserRole::DISTRIBUTOR->value,
        ]);

        $distributor->update([
            "user_id" => $distributorUser->id,
            "distributor_id" => "5"
        ]);

        $lead = Lead::factory()->create([
            "created_by_id" => $rm->id,
            "assigned_to_id" => $distributorUser->id,
        ]);

        FollowUp::factory()->create([
            "lead_id" => $lead->id,
        ]);

        // client
        $client = Lead::factory()->create([
            "created_by_id" => $rm->id,
            "assigned_to_id" => $distributorUser->id,
            "lead_status" => LeadStatus::OPPORTUNITY->value,
            "is_client" => true,
            "initial_investment_date" => Carbon::now(),
            "current_invested_amount" => fake()->numberBetween(500000, 10000000),
            "client_status" => ClientStatus::DIRECT->value,
        ]);

        $clientNominee = ClientNominee::factory()->create([
            "client_id" => $client->id,
            "relation" => "Son",
            "percentage_allocation" => 100
        ]);

        $clientInvestment = ClientInvestment::factory()->create([
            "client_id" => $client->id
        ]);

        // commission slabs
        $this->call([
            CommissionSlabSeeder::class,
        ]);
    }
}
