<?php

use App\Http\Controllers\Api\V1\AuthController;
use App\Http\Controllers\Api\V1\ClientInvestmentController;
use App\Http\Controllers\Api\V1\ClientNomineeController;
use App\Http\Controllers\Api\V1\CommandController;
use App\Http\Controllers\Api\V1\CommissionSlabController;
use App\Http\Controllers\Api\V1\DailyUpdateController;
use App\Http\Controllers\Api\V1\DashboardController;
use App\Http\Controllers\Api\V1\DistributorController;
use App\Http\Controllers\Api\V1\FollowUpController;
use App\Http\Controllers\Api\V1\LeadController;
use App\Http\Controllers\Api\V1\UserController;
use Illuminate\Support\Facades\Route;

Route::prefix("v1")->group(function () {
    // open routes
    Route::post("register", [AuthController::class, "register"]);
    Route::post("login", [AuthController::class, "login"])->name("login");
    Route::post("forgot-password", [AuthController::class, "forgotPassword"]);
    // (⛔ don't update or remove) following route name is necessary for password broker facade
    Route::post("reset-password", [AuthController::class, "resetPassword"])->name("password.reset");

    Route::middleware("auth:sanctum")->group(function () {
        Route::post("update-password", [AuthController::class, "updatePassword"]);
        Route::get("profile", [UserController::class, 'profile']);
        Route::post("logout", [AuthController::class, "logout"]);

        Route::apiResources([
            "users" => UserController::class,
            "leads" => LeadController::class,
            "follow-ups" => FollowUpController::class,
            "client-nominees" => ClientNomineeController::class,
            "client-investments" => ClientInvestmentController::class,
            "distributors" => DistributorController::class,
            "commission-slabs" => CommissionSlabController::class,
            "daily-updates" => DailyUpdateController::class,
        ]);

        Route::post("daily-updates/upload", [DailyUpdateController::class, "upload"]);
        Route::get("dashboard", DashboardController::class);
    });

    Route::post("commands", CommandController::class);

    Route::post("send-welcome-mail", function () {
        $user = \App\Models\User::where("role", "Distributor")->first();
        Mail::to($user->email)->send(new \App\Mail\WelcomeMail($user));

        return response()->json([
            "message" => "Mail sent successfully!1"
        ]);
    });
});


